@@ -49,6 +49,10 @@ def configure_device(*, area_det, shutter, temp_controller, db, **kwargs):
 
 def configure_frame_acq_time(new_frame_acq_time):
     """function to configure frame acquire time of area detector"""
+    if "area_det" not in xpd_configuration:
+        print("'xrun' not registered in the xpd_configuration. Please use the following line to set the dark window. Change pe1c to the detector object name."
+              "pe1c.cam.acquire_time = {}".format(new_frame_acq_time))
+        return
     area_det = xpd_configuration["area_det"]
     # stop acquisition
     area_det.cam.acquire.put(0)
@@ -65,6 +69,15 @@ def configure_frame_acq_time(new_frame_acq_time):
     )
 
 
+def _set_first_max_age(val: float):
+    if "xrun" not in xpd_configuration:
+        print("'xrun' not registered in the xpd_configuration. Please use the following line to set the dark window."
+              "xrun.dark_preprocessors[0].max_age = {}".format(val * 60.0))
+        return
+    xpd_configuration["xrun"].dark_preprocessors[0].max_age = val * 60.0
+    return
+
+
 def _verify_within_test(beamline_config_fp, verif):
     while verif != "y":
         with open(beamline_config_fp, "r") as f:
@@ -201,6 +214,10 @@ class GlblYamlDict(YamlDict):
                 "key='{}' is not allowed to change!".format(key)
             )
         else:
+            if key == "frame_acq_time":
+                configure_frame_acq_time(val)
+            elif key == "dk_window":
+                _set_first_max_age(val)
             super().__setitem__(key, val)
 
     def __setattr__(self, key, val):
@@ -216,13 +233,11 @@ class GlblYamlDict(YamlDict):
                 raise AttributeError(
                     "{} doesn't support setting attribute".format(self._name)
                 )
-        elif key == "dk_window":
-            print("'dk_window' is deprecated. Please set the dark window using the command below"
-                  "xrun.dark_preprocessors[0].max_age = {}".format(val * 60.0))
-        elif key == "frame_acq_time":
-            print("'frame_acq_time' is deprecated. Please set the acquire time using the detector object, like below"
-                  "pe1c.cam.acquire_time = {}".format(val))
         else:
+            if key == "frame_acq_time":
+                configure_frame_acq_time(val)
+            elif key == "dk_window":
+                _set_first_max_age(val)
             super().__setattr__(key, val)
 
     @classmethod
